cumulusci.salesforce\_api.tests package
=======================================

Submodules
----------


.. automodule:: cumulusci.salesforce_api.tests.metadata_test_strings
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.salesforce_api.tests.test_metadata
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.salesforce_api.tests.test_package_zip
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.salesforce_api.tests.test_utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.salesforce_api.tests
   :members:
   :undoc-members:
   :show-inheritance:
